@@ -16,11 +16,11 @@ from rrshare.rqUtil.rqPgsql import (PgsqlClass, client_pgsql, read_data_from_pg,
                                     read_sql_from_pg, save_data_to_postgresql)
 
 #rqFactor
-from rrshare.rqFactor.stock_RS_OH_MA import update_stock_PRS_day, update_stock_PRS_new
+#from rrshare.rqFactor.stock_RS_OH_MA import update_stock_PRS_day, update_stock_PRS_new
 
 # record data
-from rrshare.rqUpdate import (record_stock_day, record_stock_PRS, 
-                    record_stock_PRS_new,)
+#from rrshare.rqUpdate import (record_stock_day, record_stock_PRS, 
+#                    record_stock_PRS_new,)
                     #record_swl_day, record_swl_rs_valuation)
 
 # to streamlit
@@ -28,7 +28,7 @@ from rrshare.rqUpdate import (record_stock_day, record_stock_PRS,
 
 
 #record data all
-from rrshare.record_all_data import main_record
+#from rrshare.record_all_data import main_record
 
 #cli
 from rrshare.cmds import cli
