@@ -9,12 +9,12 @@ from rrshare.rqUpdate.update_stock_RS_OH_MA import record_stock_PRS, record_stoc
 
 def main_record():
     record_stock_day()
-    record_swl_day()
+    #record_swl_day()
 
     record_stock_PRS()
     record_stock_PRS_new()
 
-    record_swl_rs_valuation()
+    #record_swl_rs_valuation()
     record_swl1_index_realtime()
 
 
