@@ -11,15 +11,28 @@ warnings.filterwarnings("ignore")
 from rrshare.rqUtil import (rq_util_log_debug, rq_util_log_expection,
                                      rq_util_log_info)
 from rrshare.rqUtil import (rq_util_code_tosrccode, rq_util_code_tostr)
-from rrshare.rqUtil import rq_util_get_trade_range
-from rrshare.rqUtil import (rq_util_date_str2int,rq_util_date_int2str,
-                            rq_util_date_today, trade_date_sse,
+from rrshare.rqUtil import rq_util_get_trade_range, is_before_tradetime_secs_cn
+
+from rrshare.rqUtil import (rq_util_date_str2int,rq_util_date_int2str,is_tradeday_and_market_opened,
+                            rq_util_date_today, trade_date_sse,is_tradeday_and_market_opened,
                             rq_util_get_last_tradedate)
-from rrshare.rqFetch import (pro,fetch_delist_stock)
+from rrshare.rqFetch import (pro,fetch_delist_stock, fetch_get_stock_list)
+from rrshare.rqUtil import PERIODS
+from rrshare.rqUtil.rqParameter import startDate 
+PERIODS=PERIODS().PERIODS
+print(PERIODS)
 
-PERIODS=[5,20,60,120,250]
 
-def fetch_stock_day_adj_fillna_from_tusharepro(trade_date='20050104'):
+def fetch_stock_list_tusharepro():    
+    stock_list_l= pro.stock_basic(exchange_id='', is_hs='',list_status='L' , fields='ts_code,symbol,name,area,industry,fullname,enname,market,exchange,curr_type,list_status,list_date,delist_date,is_hs')  
+    stock_list_D= pro.stock_basic(exchange_id='', is_hs='',list_status='D' , fields='ts_code,symbol,name,area,industry,fullname,enname,market,exchange,curr_type,list_status,list_date,delist_date,is_hs')  
+    stock_list_P= pro.stock_basic(exchange_id='', is_hs='',list_status='P' , fields='ts_code,symbol,name,area,industry,fullname,enname,market,exchange,curr_type,list_status,list_date,delist_date,is_hs')          
+    stock_list=pd.concat([stock_list_l,stock_list_D],axis=0)
+    stock_list=pd.concat([stock_list,stock_list_P],axis=0)
+    return stock_list
+
+
+def fetch_stock_day_adj_fillna_from_tusharepro(trade_date=startDate):
     trade_date = trade_date.replace('-', '') #兼容设置以防日期格式为2001-10-20格式
     lastEx = None
     retry = 10
@@ -54,16 +67,19 @@ def fetch_realtime_price_stock_day_adj(src='sina'):
         time: 9:30-11:31 , 13:00-15:03
         pro.adj_factor update at 9:30
     """
-    
-    trade_date = rq_util_date_today() if rq_util_date_today().strftime('%Y-%m-%d') \
-        in trade_date_sse else  rq_util_get_last_tradedate()
+    #print(is_tradeday_and_market_opened())
+    trade_date = rq_util_date_today() if is_tradeday_and_market_opened() else  rq_util_get_last_tradedate()
+    #print(trade_date)
     trade_date = str(trade_date).replace('-','')
     quotation = eq.use(src)
+    #print(quotation)
     df_factor=pro.query('adj_factor',trade_date=trade_date)
     df_factor['code'] =  df_factor['ts_code'].apply(lambda x: x[0:6])
     all_secs = df_factor['ts_code'].values
     secs_eq = list(map(lambda x: x[0:6], all_secs))
+    #print(secs_eq)
     price_all = quotation.stocks(secs_eq)
+    #print(price_all)
     df_p = pd.DataFrame(price_all).T.reset_index()
     df_p = df_p[['index','name', 'close','now','open','high','low','turnover','volume','date','time']]
     df_p = df_p.loc[df_p['volume'] > 0]
@@ -82,13 +98,7 @@ def fetch_realtime_price_stock_day_adj(src='sina'):
     return df
 
 
-def fetch_stock_list_tusharepro():    
-    stock_list_l= pro.stock_basic(exchange_id='', is_hs='',list_status='L' , fields='ts_code,symbol,name,area,industry,fullname,enname,market,exchange,curr_type,list_status,list_date,delist_date,is_hs')  
-    stock_list_D= pro.stock_basic(exchange_id='', is_hs='',list_status='D' , fields='ts_code,symbol,name,area,industry,fullname,enname,market,exchange,curr_type,list_status,list_date,delist_date,is_hs')  
-    stock_list_P= pro.stock_basic(exchange_id='', is_hs='',list_status='P' , fields='ts_code,symbol,name,area,industry,fullname,enname,market,exchange,curr_type,list_status,list_date,delist_date,is_hs')          
-    stock_list=pd.concat([stock_list_l,stock_list_D],axis=0)
-    stock_list=pd.concat([stock_list,stock_list_P],axis=0)
-    return stock_list
+
 
 def fetch_get_stock_day_hfq_one(name, start='', end='', adj='hfq', freq='D', ma=PERIODS,adjfactor=True, type_='pd'):
     """在Tushare数据接口里，不管是旧版的一些接口还是Pro版的行情接口，都是以用户设定的end_date开始往前复权，跟所有行情软件或者财经网站上看到的前复权可能存在差异，
@@ -140,10 +150,12 @@ if __name__ == '__main__':
     #print(fetch_stock_list_tusharepro())
     #trade_date = rq_util_get_last_tradedate()
     #df1=fetch_stock_day_adj_fillna_from_tusharepro(trade_date)
+    #print(df1)
     df2 = fetch_realtime_price_stock_day_adj()
     print(df2)
     
-    #print(fetch_get_stock_day_hfq_one(name='600519.SH', start='20210101',end='20210212'))
-    pass
-
-
+   
+    
+   
+    
+    
