@@ -8,8 +8,8 @@ from rrshare.rqSU.save_tusharepro_pg import (
                                              rq_save_stock_list_pg,
                                              rq_save_stock_day_adj_fillna_pg
                                              )
-from rrshare.rqSU.save_industry_swl_list import rq_save_swl_industry_list_stock_belong
+#from rrshare.rqSU.save_industry_swl_list import rq_save_swl_industry_list_stock_belong
 
-from rrshare.rqSU.save_swsindex_realtime_pg import save_swl1_realtime
+#from rrshare.rqSU.save_swsindex_realtime_pg import save_swl1_realtime
 
 
