@@ -5,7 +5,7 @@ import tushare as ts
 import pandas as pd
 
 from rrshare.rqUtil.config_setting import setting
-from rrshare.rqUtil.rqParameter import FREQUENCE, MARKET_TYPE
+from rrshare.rqUtil.rqParameter import FREQUENCE, MARKET_TYPE, UPDATETIME
     
     
 def rq_util_format_date2str(cursor_date):
@@ -123,7 +123,7 @@ def rq_util_get_last_tradedate():
     _date = _now.strftime('%Y-%m-%d')
     #print(_now, _hour, _date)
     if  _date in trade_date_sse:
-        if _hour > 19:
+        if _hour > UPDATETIME:
             return trade_date_sse[trade_date_sse.index(_date)]
         else:
             return trade_date_sse[trade_date_sse.index(_date) - 1]
