@@ -9,7 +9,8 @@ from rrshare.rqUtil.rqLogs import (rq_util_log_debug, rq_util_log_expection,
                                              rq_util_log_info)
 
 from rrshare.rqUtil import (rq_util_get_trade_range, rq_util_get_last_tradedate, 
-                        rq_util_get_pre_trade_date, setting)
+                        rq_util_get_pre_trade_date)
+from rrshare.rqUtil.rqSetting import  setting
 
 logging.basicConfig(level=logging.INFO, format=' %(asctime)s- %(levelname)s-%(message)s')
 password_pgsql = setting['PGSQL_PASSWORD']
@@ -21,7 +22,7 @@ class PgsqlClass(ConSqlDb):
             database ='postgres',
             user='postgres', 
             password=password_pgsql,
-            host='localhost',
+            host='39.108.68.163',
             port='5432'):
 
         self.database = database
@@ -185,5 +186,5 @@ if __name__ == '__main__':
     psql.client_pg(db_name='rrshare')
     
     print(read_data_from_pg('swl_list').head())
-    print(read_table_from_pg(table_name='swl_day',client=client_pgsql('rrshare')))
+    print(read_table_from_pg(table_name='stock_day_adj_fillna',client=client_pgsql('rrshare')))
     pass
